@@ -511,18 +511,18 @@ idle_do_action (gpointer data)
   GtkWidget *widget;
   GailButton *gail_button;
 
+  GDK_THREADS_ENTER ();
+
   gail_button = GAIL_BUTTON (data);
   gail_button->action_idle_handler = 0;
 
   widget = GTK_ACCESSIBLE (gail_button)->widget;
-  if (widget == NULL)
-    /*
-     * State is defunct
-     */
-    return FALSE;
-
-  if (!GTK_WIDGET_IS_SENSITIVE (widget) || !GTK_WIDGET_VISIBLE (widget))
-    return FALSE;
+  if (widget == NULL /* State is defunct */ ||
+      !GTK_WIDGET_IS_SENSITIVE (widget) || !GTK_WIDGET_VISIBLE (widget))
+    {
+      GDK_THREADS_LEAVE ();
+      return FALSE;
+    }
 
   button = GTK_BUTTON (widget); 
   while (!g_queue_is_empty (gail_button->action_queue)) 
@@ -570,6 +570,9 @@ idle_do_action (gpointer data)
 	  break;
 	}
     }
+
+  GDK_THREADS_LEAVE ();
+
   return FALSE; 
 }
 
