@@ -1,5 +1,5 @@
 /* GAIL - The GNOME Accessibility Implementation Library
- * Copyright 2001 Sun Microsystems Inc.
+ * Copyright 2001, 2002, 2003 Sun Microsystems Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -88,7 +88,6 @@ gail_canvas_new (GtkWidget *widget)
   accessible = ATK_OBJECT (object);
   atk_object_initialize (accessible, widget);
 
-  accessible->role =  ATK_ROLE_LAYERED_PANE;
   return accessible;
 }
 
@@ -115,6 +114,8 @@ gail_canvas_real_initialize (AtkObject *obj,
                     "value_changed",
                     G_CALLBACK (adjustment_changed),
                     canvas);
+
+  obj->role =  ATK_ROLE_LAYERED_PANE;
 }
 
 static gint 
