@@ -21,6 +21,7 @@
 #include <gtk/gtk.h>
 #include "gailnotebookpage.h"
 #include <libgail-util/gailmisc.h>
+#include "gail-private-macros.h"
 
 static void      gail_notebook_page_class_init      (GailNotebookPageClass     *klass);
 
@@ -109,6 +110,7 @@ static AtkAttributeSet* gail_notebook_page_get_run_attributes
 static AtkAttributeSet* gail_notebook_page_get_default_attributes
                                                    (AtkText           *text);
 static GtkWidget* get_label_from_notebook_page     (GailNotebookPage  *page);
+static GtkWidget* find_label_child (GtkContainer *container);
 
 static gpointer parent_class = NULL;
 
@@ -182,14 +184,22 @@ notify_child_added (gpointer data)
   GailNotebookPage *page;
   AtkObject *atk_object, *atk_parent;
 
+  GDK_THREADS_ENTER ();
+
   g_return_val_if_fail (GAIL_IS_NOTEBOOK_PAGE (data), FALSE);
   page = GAIL_NOTEBOOK_PAGE (data);
   atk_object = ATK_OBJECT (data);
 
-  atk_parent = gtk_widget_get_accessible (GTK_WIDGET (page->notebook));
-  atk_object_set_parent (atk_object, atk_parent);
-  g_signal_emit_by_name (atk_parent, "children_changed::add", page->index, atk_object, NULL);
+  /* The widget page->notebook may be deleted before this handler is called */
+  if (page->notebook != NULL)
+    {
+      atk_parent = gtk_widget_get_accessible (GTK_WIDGET (page->notebook));
+      atk_object_set_parent (atk_object, atk_parent);
+      g_signal_emit_by_name (atk_parent, "children_changed::add", page->index, atk_object, NULL);
+    }
   
+  GDK_THREADS_LEAVE ();
+
   return FALSE;
 }
 
@@ -383,7 +393,7 @@ gail_notebook_page_ref_child (AtkObject *accessible,
     return NULL;
 
   child = gtk_notebook_get_nth_page (page->notebook, page->index);
-  g_return_val_if_fail (GTK_IS_WIDGET (child), NULL);
+  gail_return_val_if_fail (GTK_IS_WIDGET (child), NULL);
    
   child_obj = gtk_widget_get_accessible (child);
   g_object_ref (child_obj);
@@ -424,13 +434,15 @@ gail_notebook_page_ref_state_set (AtkObject *accessible)
       AtkObject *child;
 
       child = atk_object_ref_accessible_child (accessible, 0);
-      g_return_val_if_fail (child, state_set);
+      gail_return_val_if_fail (child, state_set);
 
       merged_state_set = state_set;
       state_set = atk_object_ref_state_set (child);
       if (atk_state_set_contains_state (state_set, ATK_STATE_VISIBLE))
         {
           atk_state_set_add_state (merged_state_set, ATK_STATE_VISIBLE);
+          if (atk_state_set_contains_state (state_set, ATK_STATE_ENABLED))
+              atk_state_set_add_state (merged_state_set, ATK_STATE_ENABLED);
           if (atk_state_set_contains_state (state_set, ATK_STATE_SHOWING))
               atk_state_set_add_state (merged_state_set, ATK_STATE_SHOWING);
 
@@ -493,7 +505,7 @@ gail_notebook_page_get_extents (AtkComponent *component,
       *height = 0;
 
       child = atk_object_ref_accessible_child (ATK_OBJECT (component), 0);
-      g_return_if_fail (child);
+      gail_return_if_fail (child);
 
       atk_component_get_position (ATK_COMPONENT (child), x, y, coord_type);
       g_object_unref (child);
@@ -822,24 +834,34 @@ get_label_from_notebook_page (GailNotebookPage *page)
     return child;
 
   if (GTK_IS_CONTAINER (child))
-    {
-      /*
-       * Child is not a label.	Search for a label in the container's children.
-       */
-      GList *children, *tmp_list;
+    child = find_label_child (GTK_CONTAINER (child));
 
-      children = gtk_container_get_children (GTK_CONTAINER (child));
+  return child;
+}
 
-      child = NULL;
-      for (tmp_list = children; tmp_list != NULL; tmp_list = tmp_list->next)
+static GtkWidget*
+find_label_child (GtkContainer *container)
+{
+  GList *children, *tmp_list;
+  GtkWidget *child;
+
+  children = gtk_container_get_children (container);
+
+  child = NULL;
+  for (tmp_list = children; tmp_list != NULL; tmp_list = tmp_list->next)
+    {
+      if (GTK_IS_LABEL (tmp_list->data))
+        {
+          child = GTK_WIDGET (tmp_list->data);
+          break;
+        }
+      else if (GTK_IS_CONTAINER (tmp_list->data))
         {
-          if (GTK_IS_LABEL (tmp_list->data))
-            {
-              child = GTK_WIDGET (tmp_list->data);
-              break;
-            }
+          child = find_label_child (GTK_CONTAINER (tmp_list->data));
+          if (child)
+            break;
         }
-     g_list_free (children); 
     }
+  g_list_free (children);
   return child;
 }
