@@ -23,6 +23,7 @@
 #include "gailutil.h"
 #include "gailtoplevel.h"
 #include "gailwindow.h"
+#include "gail-private-macros.h"
 
 static void		gail_util_class_init			(GailUtilClass		*klass);
 
@@ -432,7 +433,7 @@ state_event_watcher (GSignalInvocationHint  *hint,
     return FALSE;
 
   event = g_value_get_boxed (param_values + 1);
-  g_return_val_if_fail (event->type == GDK_WINDOW_STATE, FALSE);
+  gail_return_val_if_fail (event->type == GDK_WINDOW_STATE, FALSE);
   widget = GTK_WIDGET (object);
 
   if (event->new_window_state & GDK_WINDOW_STATE_MAXIMIZED)
@@ -479,7 +480,7 @@ window_added (AtkObject *atk_obj,
   g_return_if_fail (GAIL_IS_WINDOW (child));
 
   widget = GTK_ACCESSIBLE (child)->widget;
-  g_return_if_fail (widget);
+  gail_return_if_fail (widget);
 
   g_signal_connect (widget, "focus-in-event",  
                     (GCallback) window_focus, NULL);
@@ -500,7 +501,7 @@ window_removed (AtkObject *atk_obj,
   g_return_if_fail (GAIL_IS_WINDOW (child));
 
   widget = GTK_ACCESSIBLE (child)->widget;
-  g_return_if_fail (widget);
+  gail_return_if_fail (widget);
 
   window = GTK_WINDOW (widget);
   /*
