@@ -22,6 +22,7 @@
 #include "gailwidget.h"
 #include "gailnotebookpage.h"
 #include "gailcanvaswidget.h"
+#include "gail-private-macros.h"
 
 extern GtkWidget *focus_widget;
 
@@ -277,7 +278,7 @@ gail_widget_get_description (AtkObject *accessible)
       GtkAccessible *obj = GTK_ACCESSIBLE (accessible);
       GtkTooltipsData *data;
 
-      g_return_val_if_fail (obj, NULL);
+      gail_return_val_if_fail (obj, NULL);
 
       if (obj->widget == NULL)
         /*
@@ -285,7 +286,7 @@ gail_widget_get_description (AtkObject *accessible)
          */
         return NULL;
  
-      g_return_val_if_fail (GTK_WIDGET (obj->widget), NULL);
+      gail_return_val_if_fail (GTK_WIDGET (obj->widget), NULL);
     
       data = gtk_tooltips_data_get (obj->widget);
       if (data == NULL)
@@ -314,7 +315,7 @@ gail_widget_get_parent (AtkObject *accessible)
          * State is defunct
          */
         return NULL;
-      g_return_val_if_fail (GTK_IS_WIDGET (widget), NULL);
+      gail_return_val_if_fail (GTK_IS_WIDGET (widget), NULL);
 
       parent_widget = widget->parent;
       if (parent_widget == NULL)
@@ -408,7 +409,7 @@ gail_widget_ref_relation_set (AtkObject *obj)
   AtkObject *array[1];
   AtkRelation* relation;
 
-  g_return_val_if_fail (GAIL_IS_WIDGET (obj), NULL);
+  gail_return_val_if_fail (GAIL_IS_WIDGET (obj), NULL);
 
   widget = GTK_ACCESSIBLE (obj)->widget;
   if (widget == NULL)
@@ -603,11 +604,11 @@ gail_widget_get_index_in_parent (AtkObject *accessible)
         }
     }
 
-  g_return_val_if_fail (GTK_IS_WIDGET (widget), -1);
+  gail_return_val_if_fail (GTK_IS_WIDGET (widget), -1);
   parent_widget = widget->parent;
   if (parent_widget == NULL)
     return -1;
-  g_return_val_if_fail (GTK_IS_CONTAINER (parent_widget), -1);
+  gail_return_val_if_fail (GTK_IS_CONTAINER (parent_widget), -1);
 
   children = gtk_container_get_children (GTK_CONTAINER (parent_widget));
 
@@ -682,7 +683,7 @@ gail_widget_get_extents (AtkComponent   *component,
      */
     return;
 
-  g_return_if_fail (GTK_IS_WIDGET (widget));
+  gail_return_if_fail (GTK_IS_WIDGET (widget));
 
   *width = widget->allocation.width;
   *height = widget->allocation.height;
@@ -733,7 +734,7 @@ gail_widget_get_size (AtkComponent   *component,
      */
     return;
 
-  g_return_if_fail (GTK_IS_WIDGET (widget));
+  gail_return_if_fail (GTK_IS_WIDGET (widget));
 
   *width = widget->allocation.width;
   *height = widget->allocation.height;
@@ -754,7 +755,7 @@ gail_widget_grab_focus (AtkComponent   *component)
   GtkWidget *widget = GTK_ACCESSIBLE (component)->widget;
   GtkWidget *toplevel;
 
-  g_return_val_if_fail (GTK_IS_WIDGET (widget), FALSE);
+  gail_return_val_if_fail (GTK_IS_WIDGET (widget), FALSE);
   if (GTK_WIDGET_CAN_FOCUS (widget))
     {
       gtk_widget_grab_focus (widget);
@@ -789,7 +790,7 @@ gail_widget_set_extents (AtkComponent   *component,
      * Object is defunct
      */
     return FALSE;
-  g_return_val_if_fail (GTK_IS_WIDGET (widget), FALSE);
+  gail_return_val_if_fail (GTK_IS_WIDGET (widget), FALSE);
 
   if (GTK_WIDGET_TOPLEVEL (widget))
     {
@@ -833,7 +834,7 @@ gail_widget_set_position (AtkComponent   *component,
      * Object is defunct
      */
     return FALSE;
-  g_return_val_if_fail (GTK_IS_WIDGET (widget), FALSE);
+  gail_return_val_if_fail (GTK_IS_WIDGET (widget), FALSE);
 
   if (GTK_WIDGET_TOPLEVEL (widget))
     {
@@ -874,7 +875,7 @@ gail_widget_set_size (AtkComponent   *component,
      * Object is defunct
      */
     return FALSE;
-  g_return_val_if_fail (GTK_IS_WIDGET (widget), FALSE);
+  gail_return_val_if_fail (GTK_IS_WIDGET (widget), FALSE);
 
   if (GTK_WIDGET_TOPLEVEL (widget))
     {
@@ -886,7 +887,7 @@ gail_widget_set_size (AtkComponent   *component,
 }
 
 #if 0
-static GtkWidget*
+static GtkWidget
 _gail_widget_get_parent (GtkWidget* widget)
 {
   GtkWidget *parent_widget;
